.. raw :: html

    <!-- Generated by generate_authors_table.py -->
    <div class="sk-authors-container">
    <style>
      img.avatar {border-radius: 10px;}
    </style>
    <div>
    <a href='https://github.com/ArturoAmorQ'><img src='https://avatars.githubusercontent.com/u/86408019?v=4' class='avatar' /></a> <br />
    <p>Arturo Amor</p>
    </div>
    <div>
    <a href='https://github.com/lucyleeow'><img src='https://avatars.githubusercontent.com/u/23182829?v=4' class='avatar' /></a> <br />
    <p>Lucy Liu</p>
    </div>
    <div>
    <a href='https://github.com/marenwestermann'><img src='https://avatars.githubusercontent.com/u/17019042?v=4' class='avatar' /></a> <br />
    <p>Maren Westermann</p>
    </div>
    <div>
    <a href='https://github.com/Charlie-XIAO'><img src='https://avatars.githubusercontent.com/u/108576690?v=4' class='avatar' /></a> <br />
    <p>Yao Xiao</p>
    </div>
    </div>
